<?php

namespace Litecms\Sitecontent\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Sitecontent\Models\ManageContent;

class ManageContentPolicy
{

    /**
     * Determine if the given user can view the manage_content.
     *
     * @param UserPolicy $user
     * @param ManageContent $manage_content
     *
     * @return bool
     */
    public function view(UserPolicy $user, ManageContent $manage_content)
    {
        if ($user->canDo('sitecontent.manage_content.view') && $user->isAdmin()) {
            return true;
        }

        return $manage_content->user_id == user_id() && $manage_content->user_type == user_type();
    }

    /**
     * Determine if the given user can create a manage_content.
     *
     * @param UserPolicy $user
     * @param ManageContent $manage_content
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('sitecontent.manage_content.create');
    }

    /**
     * Determine if the given user can update the given manage_content.
     *
     * @param UserPolicy $user
     * @param ManageContent $manage_content
     *
     * @return bool
     */
    public function update(UserPolicy $user, ManageContent $manage_content)
    {
        if ($user->canDo('sitecontent.manage_content.edit') && $user->isAdmin()) {
            return true;
        }

        return $manage_content->user_id == user_id() && $manage_content->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given manage_content.
     *
     * @param UserPolicy $user
     * @param ManageContent $manage_content
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ManageContent $manage_content)
    {
        return $manage_content->user_id == user_id() && $manage_content->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given manage_content.
     *
     * @param UserPolicy $user
     * @param ManageContent $manage_content
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ManageContent $manage_content)
    {
        if ($user->canDo('sitecontent.manage_content.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given manage_content.
     *
     * @param UserPolicy $user
     * @param ManageContent $manage_content
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ManageContent $manage_content)
    {
        if ($user->canDo('sitecontent.manage_content.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
